@@ -10,21 +10,25 @@ from shutil import copy
 from shutil import move
 from sqlite3 import Connection
 from sqlite3 import Cursor
-from sqlite3 import DatabaseError
+from sqlite3 import ProgrammingError
 from sqlite3 import connect
 from typing import Generator
+from typing import Iterable
 from typing import Optional
 from typing import Union
 
 from chardet import detect as detect_encoding
 from filetype import guess_extension as filetype_guess_extension
 from psutil import AccessDenied
-from psutil import Error
 from psutil import NoSuchProcess
 from psutil import Process
 from psutil import process_iter
 
 from .__version__ import __version__
+from .exceptions import MultipleConnections
+from .exceptions import VersionMismatch
+from .selector import Selector
+from .selector import selector_to_sql
 from .tables import journals_table
 from .tables import list_columns
 from .tables import make_journals_table
@@ -34,12 +38,11 @@ from .tables import make_users_table
 from .tables import settings_table
 from .tables import submissions_table
 from .tables import users_table
+from .types import Entry
+from .types import Key
+from .types import Value
 from .update import update_database
 
-Key = Union[str, int, float]
-Value = Union[str, int, float, None]
-Entry = dict[str, Union[list[str], Value]]
-
 
 def guess_extension(file: Optional[bytes], default: str = "") -> str:
     if not file:
@@ -61,23 +64,19 @@ def tiered_path(id_: Union[int, str], depth: int = 5, width: int = 2) -> Path:
     return Path(*[id_str[n:n + width] for n in range(0, depth * width, width)])
 
 
-def check_version(version_a: str, raise_for_error: bool = True, *, major: bool = True, minor: bool = True,
-                  patch: bool = True, version_b: str = __version__
-                  ) -> Optional[DatabaseError]:
-    err: Optional[DatabaseError] = None
-    if version_a == version_b:
+def check_version(version_a: str, *, major: bool = True, minor: bool = True, patch: bool = True,
+                  version_b: str = __version__
+                  ) -> Optional[VersionMismatch]:
+    if not version_a:
+        return VersionMismatch(f"version missing")
+    elif version_a == version_b:
         return None
-    elif not version_a:
-        err = DatabaseError(f"version error: {version_a}")
     elif (v_a := version_a.split("."))[0] != (v_b := version_b.split("."))[0]:
-        err = DatabaseError(f"major version is not latest: {v_a[0]} != {v_b[0]}") if major else None
+        return VersionMismatch(f"major version is not latest: {v_a[0]} != {v_b[0]}") if major else None
     elif v_a[1] != v_b[1]:
-        err = DatabaseError(f"minor version is not latest: {v_a[1]} != {v_b[1]}") if minor else None
+        return VersionMismatch(f"minor version is not latest: {v_a[1]} != {v_b[1]}") if minor else None
     elif v_a[2] != v_b[2]:
-        err = DatabaseError(f"patch version is not latest: {v_a[2]} != {v_b[2]}") if patch else None
-    if err is not None and raise_for_error:
-        raise err
-    return err
+        return VersionMismatch(f"patch version is not latest: {v_a[2]} != {v_b[2]}") if patch else None
 
 
 def copy_folder(src: Path, dest: Path):
@@ -96,11 +95,10 @@ def clean_username(username: str) -> str:
 def copy_cursors(db_dest: 'FADatabase', cursors: list['FADatabaseCursor'] = None, replace: bool = True):
     if not cursors:
         return
-    assert (e := check_version(version_dest := db_dest.version, raise_for_error=False, patch=False)) is None, \
+    assert (e := check_version(version_dest := db_dest.version)) is None, \
         f"Destination database is not up to date. {e.args[0]}"
-    assert all(
-        check_version(c.table.database.version, raise_for_error=False, patch=False, version_b=version_dest) is None
-        for c in cursors), "Cursors must point to a database with the same version as the destination database"
+    assert all(check_version(c.table.database.version, version_b=version_dest) is None for c in cursors), \
+        "Cursors must point to a database with the same version as the destination database"
     assert all(set(c.columns) == set(c.table.columns) for c in cursors), "Cursors must contain all table columns"
 
     dest_files: Path = db_dest.files_folder
@@ -137,7 +135,7 @@ class FADatabaseTable:
 
     def __getitem__(self, key: Union[Key, Entry]) -> Optional[Entry]:
         key = key if isinstance(key, dict) else {self.column_id: key}
-        return entry[0] if (entry := list(self.select(key))) else None
+        return self.select({"$eq": key}).fetchone()
 
     def __setitem__(self, key: Key, values: Entry):
         values = self.format_dict(values)
@@ -201,31 +199,16 @@ class FADatabaseTable:
         obj = {k: format_list(v) if isinstance(v := obj.get(k, ""), list) else v for k in self.columns}
         return obj
 
-    def select(self, query: dict[str, Union[list[Value], Value]] = None, columns: list[str] = None,
-               query_and: bool = True, query_and_values: bool = False, like: bool = False,
+    def select(self, query: Selector = None, values: list[Value] = None, columns: list[str] = None,
                order: list[str] = None, limit: int = 0, offset: int = 0
                ) -> 'FADatabaseCursor':
-        query = query or {}
-        query = {k: [v] if not isinstance(v, list) else v for k, v in query.items()}
-        query = {k: vs for k, vs in query.items() if vs}
-        order = order or []
-        columns = columns or self.columns
-        op: str = "like" if like else "="
-        logic: str = "AND" if query_and else "OR"
-        logic_values: str = "AND" if query_and_values else "OR"
-        where_str: str = f" {logic} ".join(map(lambda q: f"({q})", [
-            f" {logic_values} ".join([f"{k} {op} ?"] * len(vs))
-            for k, vs in query.items()
-        ]))
-        order_str = ",".join(order)
-        cursor: Cursor = self.database.connection.execute(
-            f"""SELECT {','.join(columns)} FROM {self.table}
-            {f' WHERE {where_str} ' if where_str else ''}
-            {f' ORDER BY {order_str} ' if order_str else ''}
-            {f' LIMIT {limit} ' if limit > 0 else ''}
-            {f' OFFSET {offset} ' if limit > 0 and offset > 0 else ''}""",
-            [v for values in query.values() for v in values]
-        )
+        cursor: Cursor = self.database.execute(
+            f"""SELECT {','.join(columns := columns or self.columns)} FROM {self.table}
+                    {f' WHERE {selector_to_sql(query)}' if query else ''}
+                    {f' ORDER BY {",".join(order)}' if order else ''}
+                    {f' LIMIT {limit}' if limit > 0 else ''}
+                    {f' OFFSET {offset}' if limit > 0 and offset > 0 else ''}""",
+            values or [])
         return FADatabaseCursor(cursor, columns, self)
 
     def select_sql(self, where: str = "", values: list[Value] = None, columns: list[str] = None,
@@ -363,17 +346,17 @@ class FADatabaseUsers(FADatabaseTable):
             return
         self.update({"FOLDERS": format_list([f"!{f.strip('!')}" for f in user_entry["FOLDERS"]])}, user)
 
-    def add_user_folder(self, user: str, folder: str):
+    def add_user_folder(self, user: str, folder: str) -> bool:
         if not (user_entry := self[(user := clean_username(user))]):
-            return
+            return False
         elif (folder := folder.lower()) in user_entry["FOLDERS"]:
-            return
+            return False
         elif f"!{folder}" in user_entry["FOLDERS"]:
             self.remove_user_folder(user, f"!{folder}")
-        self.add_to_list(user, {"FOLDERS": [folder]})
+        return self.add_to_list(user, {"FOLDERS": [folder]})
 
-    def remove_user_folder(self, user: str, folder: str):
-        self.remove_from_list(clean_username(user), {"FOLDERS": [folder.lower()]})
+    def remove_user_folder(self, user: str, folder: str) -> bool:
+        return self.remove_from_list(clean_username(user), {"FOLDERS": [folder.lower()]})
 
 
 class FADatabaseCursor:
@@ -392,6 +375,12 @@ class FADatabaseCursor:
     def __iter__(self) -> Generator[Entry, None, None]:
         return self.entries
 
+    def fetchone(self):
+        return next(self.entries, None)
+
+    def fetchall(self):
+        return list(self.entries)
+
 
 class FADatabase:
     def __init__(self, database_path: Union[str, PathLike]):
@@ -428,6 +417,13 @@ class FADatabase:
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.close()
 
+    def is_open(self) -> bool:
+        try:
+            self.connection.execute("SELECT * FROM sqlite_master")
+            return True
+        except ProgrammingError:
+            return False
+
     @property
     def tables(self) -> list[str]:
         return [
@@ -474,22 +470,29 @@ class FADatabase:
 
     def check_version(self, raise_for_error: bool = True, *, major: bool = True, minor: bool = True, patch: bool = True,
                       version: str = __version__
-                      ) -> Optional[DatabaseError]:
-        return check_version(self.version, raise_for_error=raise_for_error, major=major, minor=minor, patch=patch,
-                             version_b=version)
+                      ) -> Optional[VersionMismatch]:
+        err: Optional[VersionMismatch] = check_version(
+            self.version, major=major, minor=minor, patch=patch, version_b=version)
+        if err is not None and raise_for_error:
+            raise err
+        return err
 
     def check_connection(self, raise_for_error: bool = True) -> list[Process]:
         ps: list[Process] = []
+        database_path: str = str(self.database_path)
         for process in process_iter():
             try:
-                if process.is_running() and any(self.database_path == f.path for f in process.open_files()):
+                if process.is_running() and any(database_path == f.path for f in process.open_files()):
                     ps.append(process)
                 if len(ps) > 1 and raise_for_error:
-                    raise Error(f"Multiple connections to database: {ps}")
+                    raise MultipleConnections(f"Multiple connections to database: {ps}")
             except (NoSuchProcess, AccessDenied):
                 pass
         return ps
 
+    def execute(self, sql: str, parameters: Iterable) -> Cursor:
+        return self.connection.execute(sql, parameters)
+
     def commit(self):
         self.connection.commit()
         self.committed_changes = self.total_changes
