@@ -850,13 +850,71 @@ def make_database_4_11(db: Connection) -> Connection:
     return db
 
 
+def make_database_4_18(db: Connection) -> Connection:
+    db.execute(
+        f"""CREATE TABLE IF NOT EXISTS USERS
+        (USERNAME TEXT UNIQUE NOT NULL CHECK (length(USERNAME) > 0),
+        FOLDERS TEXT NOT NULL,
+        PRIMARY KEY (USERNAME ASC));"""
+    )
+
+    db.execute(
+        """CREATE TABLE IF NOT EXISTS SUBMISSIONS
+        (ID INT UNIQUE NOT NULL CHECK (ID > 0),
+        AUTHOR TEXT NOT NULL CHECK (length(AUTHOR) > 0),
+        TITLE TEXT NOT NULL,
+        DATE DATE NOT NULL CHECK (DATE==strftime('%Y-%m-%dT%H:%M',DATE)),
+        DESCRIPTION TEXT NOT NULL,
+        TAGS TEXT NOT NULL,
+        CATEGORY TEXT NOT NULL,
+        SPECIES TEXT NOT NULL,
+        GENDER TEXT NOT NULL,
+        RATING TEXT NOT NULL,
+        TYPE TEXT NOT NULL CHECK (TYPE IN ('image', 'music', 'text', 'flash')),
+        FILEURL TEXT NOT NULL,
+        FILEEXT TEXT NOT NULL,
+        FILESAVED INT NOT NULL CHECK (FILESAVED in (0, 1, 10, 11)),
+        FAVORITE TEXT NOT NULL,
+        MENTIONS TEXT NOT NULL,
+        FOLDER TEXT NOT NULL CHECK (FOLDER IN ('gallery', 'scraps')),
+        USERUPDATE INT NOT NULL CHECK (USERUPDATE in (0, 1)),
+        PRIMARY KEY (ID ASC));"""
+    )
+
+    db.execute(
+        """CREATE TABLE IF NOT EXISTS JOURNALS
+        (ID INT UNIQUE NOT NULL CHECK (ID > 0),
+        AUTHOR TEXT NOT NULL CHECK (length(AUTHOR) > 0),
+        TITLE TEXT NOT NULL,
+        DATE DATE NOT NULL CHECK (DATE==strftime('%Y-%m-%dT%H:%M',DATE)),
+        CONTENT TEXT NOT NULL,
+        MENTIONS TEXT NOT NULL,
+        USERUPDATE INT NOT NULL CHECK (USERUPDATE in (0, 1)),
+        PRIMARY KEY (ID ASC));""",
+    )
+
+    db.execute(
+        """CREATE TABLE IF NOT EXISTS SETTINGS
+        (SETTING TEXT UNIQUE NOT NULL CHECK (length(SETTING) > 0),
+        SVALUE TEXT NOT NULL CHECK (length(SVALUE) > 0),
+        PRIMARY KEY (SETTING ASC));"""
+    )
+
+    db.execute(f"INSERT OR IGNORE INTO SETTINGS (SETTING, SVALUE) VALUES (?, ?)", ["HISTORY", "[]"])
+    db.execute(f"INSERT OR IGNORE INTO SETTINGS (SETTING, SVALUE) VALUES (?, ?)", ["COOKIES", "{}"])
+    db.execute(f"INSERT OR IGNORE INTO SETTINGS (SETTING, SVALUE) VALUES (?, ?)", ["FILESFOLDER", "FA.files"])
+    db.execute(f"INSERT OR IGNORE INTO SETTINGS (SETTING, SVALUE) VALUES (?, ?)", ["VERSION", "4.18.0"])
+
+    db.commit()
+
+    return db
+
+
 def make_database(path: str, make_function: Callable[[Connection], Connection]):
     make_function(connect_database(path)).close()
 
 
-def update_2_7_to_3(db: Connection, db_path: str, db_new_path: str):
-    print("Updating 2.7.0 to 3.0.0")
-
+def update_3_0(db: Connection, db_path: str, db_new_path: str):
     make_database(db_new_path, make_database_3)
 
     # Transferring entries
@@ -931,8 +989,8 @@ def update_2_7_to_3(db: Connection, db_path: str, db_new_path: str):
     print()
     if sub_not_found:
         print(f"{len(sub_not_found)} submissions not found in FA.files\n" +
-              "Writing ID's to FA_update_2_7_to_3.txt")
-        with open("FA_update_2_7_to_3.txt", "w") as f:
+              "Writing ID's to FA_update_3_0.txt")
+        with open("FA_update_3_0.txt", "w") as f:
             for i, sub in enumerate(sorted(sub_not_found)):
                 print(i, end="\r", flush=True)
                 f.write(str(sub) + "\n")
@@ -953,9 +1011,7 @@ def update_2_7_to_3(db: Connection, db_path: str, db_new_path: str):
     db.execute("update db_new.SETTINGS set SVALUE = ? where SETTING = 'USRN'", [str(count(db, "USERS"))])
 
 
-def update_3_0_to_3_1(db: Connection, db_path: str, db_new_path: str):
-    print("Updating 3.0.0 to 3.1.0")
-
+def update_3_1(db: Connection, db_path: str, db_new_path: str):
     make_database(db_new_path, make_database_3_1)
 
     # Transferring entries
@@ -980,9 +1036,7 @@ def update_3_0_to_3_1(db: Connection, db_path: str, db_new_path: str):
     db.execute("UPDATE db_new.USERS SET FOLDERS = replace(FOLDERS, 'Extras', 'mentions_all')")
 
 
-def update_3_1_to_3_2(db: Connection, db_path: str, db_new_path: str):
-    print("Updating 3.1.0 to 3.2.0")
-
+def update_3_2(db: Connection, db_path: str, db_new_path: str):
     make_database(db_new_path, make_database_3_2)
 
     # Transferring entries
@@ -1003,9 +1057,7 @@ def update_3_1_to_3_2(db: Connection, db_path: str, db_new_path: str):
     db.execute("UPDATE db_new.USERS SET JOURNALS = ''")
 
 
-def update_3_2_to_3_3(db: Connection, db_path: str, db_new_path: str):
-    print("Updating 3.2.0 to 3.3.0")
-
+def update_3_3(db: Connection, db_path: str, db_new_path: str):
     make_database(db_new_path, make_database_3_3)
 
     # Transferring entries
@@ -1036,9 +1088,7 @@ def update_3_2_to_3_3(db: Connection, db_path: str, db_new_path: str):
                    json_dumps([[float(last_update[0]), "update"]]))
 
 
-def update_3_4_to_3_5(db: Connection, db_path: str, db_new_path: str):
-    print("Updating 3.4.0 to 3.5.0")
-
+def update_3_5(db: Connection, db_path: str, db_new_path: str):
     make_database(db_new_path, make_database_3_3)
 
     # Transferring entries
@@ -1071,9 +1121,7 @@ def update_3_4_to_3_5(db: Connection, db_path: str, db_new_path: str):
     db.execute("UPDATE db_new.SETTINGS SET SVALUE = ? WHERE SETTING = 'VERSION'", ["3.5.0"])
 
 
-def update_3_8_to_4(db: Connection, db_path: str, db_new_path: str):
-    print("Updating 3.8.0 to 4.0.0")
-
+def update_4_0(db: Connection, db_path: str, db_new_path: str):
     make_database(db_new_path, make_database_4)
 
     # Transferring entries
@@ -1097,9 +1145,7 @@ def update_3_8_to_4(db: Connection, db_path: str, db_new_path: str):
     )
 
 
-def update_4_2_to_4_3(db: Connection, db_path: str, db_new_path: str):
-    print("Updating 4.2.0 to 4.3.0")
-
+def update_4_3(db: Connection, db_path: str, db_new_path: str):
     make_database(db_new_path, make_database_4_3)
 
     # Transferring entries
@@ -1123,9 +1169,7 @@ def update_4_2_to_4_3(db: Connection, db_path: str, db_new_path: str):
     )
 
 
-def update_4_3_to_4_4(db: Connection, db_path: str, db_new_path: str):
-    print("Updating 4.3.0 to 4.4.0")
-
+def update_4_4(db: Connection, db_path: str, db_new_path: str):
     make_database(db_new_path, make_database_4_4)
 
     # Transferring entries
@@ -1149,7 +1193,8 @@ def update_4_3_to_4_4(db: Connection, db_path: str, db_new_path: str):
     )
 
     print("Updating favorites from users entries")
-    for n, u, fs in db.execute("select row_number() over (), USERNAME, FAVORITES from db_new.USERS where FAVORITES != ''"):
+    for n, u, fs in db.execute(
+            "select row_number() over (), USERNAME, FAVORITES from db_new.USERS where FAVORITES != ''"):
         print(n, end="\r", flush=True)
         for f in map(int, filter(bool, fs.split(","))):
             f_us: Optional[tuple] = db.execute(f"select FAVORITE from db_new.SUBMISSIONS where ID = {f}").fetchone()
@@ -1161,9 +1206,7 @@ def update_4_3_to_4_4(db: Connection, db_path: str, db_new_path: str):
             db.execute(f"update db_new.SUBMISSIONS set FAVORITE = ? where ID = {f}", [f_us_new])
 
 
-def update_4_4_to_4_5(db: Connection, db_path: str, db_new_path: str):
-    print("Updating 4.4.0 to 4.5.0")
-
+def update_4_5(db: Connection, db_path: str, db_new_path: str):
     make_database(db_new_path, make_database_4_5)
 
     # Transferring entries
@@ -1224,9 +1267,7 @@ def update_4_4_to_4_5(db: Connection, db_path: str, db_new_path: str):
             f.write("\n".join(f"{u} {s}" for u, s in double_folders))
 
 
-def update_4_5_to_4_6(db: Connection, db_path: str, db_new_path: str):
-    print("Updating 4.5.0 to 4.6.0")
-
+def update_4_6(db: Connection, db_path: str, db_new_path: str):
     make_database(db_new_path, make_database_4_6)
 
     # Transferring entries
@@ -1258,9 +1299,7 @@ def update_4_5_to_4_6(db: Connection, db_path: str, db_new_path: str):
     )
 
 
-def update_4_6_to_4_7(db: Connection, db_path: str, db_new_path: str):
-    print("Updating 4.6.0 to 4.7.0")
-
+def update_4_7(db: Connection, db_path: str, db_new_path: str):
     make_database(db_new_path, make_database_4_7)
 
     # Transferring entries
@@ -1292,9 +1331,7 @@ def update_4_6_to_4_7(db: Connection, db_path: str, db_new_path: str):
             db.execute("update db_new.JOURNALS set MENTIONS = ? where ID = ?", (",".join(mentions), i))
 
 
-def update_4_7_to_4_8(db: Connection, db_path: str, db_new_path: str):
-    print("Updating 4.7.0 to 4.8.0")
-
+def update_4_8(db: Connection, db_path: str, db_new_path: str):
     make_database(db_new_path, make_database_4_8)
 
     # Transferring entries
@@ -1339,9 +1376,7 @@ def update_4_7_to_4_8(db: Connection, db_path: str, db_new_path: str):
         db.execute("update db_new.JOURNALS set MENTIONS = ? where ID = ?", (ms, i))
 
 
-def update_4_8_to_4_9(db: Connection, db_path: str, db_new_path: str):
-    print("Updating 4.8.0 to 4.9.0")
-
+def update_4_9(db: Connection, db_path: str, db_new_path: str):
     make_database(db_new_path, make_database_4_9)
 
     # Transferring entries
@@ -1406,9 +1441,7 @@ def update_4_8_to_4_9(db: Connection, db_path: str, db_new_path: str):
             f.write("\n".join(f"{i} {e}" for i, e in blank_extensions))
 
 
-def update_4_10_4_11(db: Connection, db_path: str, db_new_path: str):
-    print("Updating 4.10.0 to 4.11.0")
-
+def update_4_11(db: Connection, db_path: str, db_new_path: str):
     make_database(db_new_path, make_database_4_11)
 
     # Transferring entries
@@ -1431,7 +1464,26 @@ def update_4_10_4_11(db: Connection, db_path: str, db_new_path: str):
         db.execute("UPDATE db_new.SUBMISSIONS SET FILESAVED = ? WHERE ID = ?", (f, i))
 
 
-def update_wrapper(db: Connection, function: Callable[[Connection, str, str], None], prefix_old: str) -> Connection:
+def update_4_18(db: Connection, _db_path: str, db_new_path: str):
+    make_database(db_new_path, make_database_4_18)
+
+    # Transferring entries
+    print("Transferring entries")
+    db.execute(f"ATTACH DATABASE '{db_new_path}' AS db_new")
+    db.execute("INSERT OR IGNORE INTO db_new.USERS SELECT * FROM USERS")
+    db.execute("""INSERT OR IGNORE INTO db_new.SUBMISSIONS
+               SELECT ID, AUTHOR, TITLE, strftime('%Y-%m-%dT%H:%M', DATE), DESCRIPTION, TAGS, CATEGORY, SPECIES,
+               GENDER, RATING, TYPE, FILEURL,FILEEXT, FILESAVED, FAVORITE, MENTIONS, FOLDER, USERUPDATE
+               FROM SUBMISSIONS""")
+    db.execute("""INSERT OR IGNORE INTO db_new.JOURNALS
+               SELECT ID, AUTHOR, TITLE, strftime('%Y-%m-%dT%H:%M', DATE), CONTENT, MENTIONS, USERUPDATE
+               FROM JOURNALS""")
+    db.execute("INSERT OR REPLACE INTO db_new.SETTINGS SELECT * FROM SETTINGS WHERE SETTING NOT IN ('VERSION')")
+
+
+def update_wrapper(db: Connection, function: Callable[[Connection, str, str], None], version_old: str, version_new: str
+                   ) -> Connection:
+    print(f"Updating {version_old} to {version_new}")
     db_path: str = dp if (dp := database_path(db)) else "FA.db"
     db_new_path: str = join(dirname(db_path), "new_" + basename(db_path))
     try:
@@ -1439,7 +1491,7 @@ def update_wrapper(db: Connection, function: Callable[[Connection, str, str], No
         db.commit()
         db.close()
         db = None
-        move(db_path, join(dirname(db_path), prefix_old + basename(db_path)))
+        move(db_path, join(dirname(db_path), f"v{version_old.replace('.', '_')}_" + basename(db_path)))
         move(db_new_path, db_path)
         return connect_database(db_path)
     except KeyboardInterrupt:
@@ -1471,40 +1523,36 @@ def update_database(db: Connection, version: str) -> Connection:
         raise DatabaseError("Database version is newer than program.")
     elif compare_versions(db_version, "2.7.0") < 0:
         raise DatabaseError("Update does not support versions lower than 2.11.2")
-    elif compare_versions(db_version, "3.0.0") < 0:
-        db = update_wrapper(db, update_2_7_to_3, "v2_7_")  # 2.7.x to 3.0.0
-    elif compare_versions(db_version, "3.1.0") < 0:
-        db = update_wrapper(db, update_3_0_to_3_1, "v3_0_")  # 3.0.x to 3.1.0
-    elif compare_versions(db_version, "3.2.0") < 0:
-        db = update_wrapper(db, update_3_1_to_3_2, "v3_1_")  # 3.1.x to 3.2.0
-    elif compare_versions(db_version, "3.3.0") < 0:
-        db = update_wrapper(db, update_3_2_to_3_3, "v3_2_")  # 3.2.x to 3.3.0
-    elif compare_versions(db_version, "3.4.0") < 0:
-        db = update_version(db, db_version, "3.4.0")  # 3.3.x to 3.4.0
-    elif compare_versions(db_version, "3.5.0") < 0:
-        db = update_wrapper(db, update_3_4_to_3_5, "v3_4_")  # 3.4.x to 3.5.0
-    elif compare_versions(db_version, "3.8.0") < 0:
-        db = update_version(db, db_version, "3.8.0")  # 3.5.0-3.7.x to 3.8.0
-    elif compare_versions(db_version, "4.0.0") < 0:
-        db = update_wrapper(db, update_3_8_to_4, "v3_8_")  # 3.8.x to 4.0.0
-    elif compare_versions(db_version, "4.3.0") < 0:
-        db = update_wrapper(db, update_4_2_to_4_3, "v4_2_")  # 4.0.0-4.2.x to 4.3.0
-    elif compare_versions(db_version, "4.4.0") < 0:
-        db = update_wrapper(db, update_4_3_to_4_4, "v4_3_")  # 4.3.x to 4.4.0
-    elif compare_versions(db_version, "4.5.0") < 0:
-        db = update_wrapper(db, update_4_4_to_4_5, "v4_4_")  # 4.4.x to 4.5.0
-    elif compare_versions(db_version, "4.6.0") < 0:
-        db = update_wrapper(db, update_4_5_to_4_6, "v4_5_")  # 4.5.x to 4.6.0
-    elif compare_versions(db_version, "4.7.0") < 0:
-        db = update_wrapper(db, update_4_6_to_4_7, "v4_6_")  # 4.6.x to 4.7.0
-    elif compare_versions(db_version, "4.8.0") < 0:
-        db = update_wrapper(db, update_4_7_to_4_8, "v4_7_")  # 4.7.x to 4.8.0
-    elif compare_versions(db_version, "4.9.0") < 0:
-        db = update_wrapper(db, update_4_8_to_4_9, "v4_8_")  # 4.8.x to 4.9.0
-    elif compare_versions(db_version, "4.10.0") < 0:
-        db = update_version(db, db_version, "4.10.0")  # 4.9.x to 4.10.0
-    elif compare_versions(db_version, "4.11.0") < 0:
-        db = update_wrapper(db, update_4_10_4_11, "v4_10_")  # 4.10.x to 4.11.0
+    elif compare_versions(db_version, v := "3.0.0") < 0:
+        db = update_wrapper(db, update_3_0, db_version, v)  # 2.7.x to 3.0.0
+    elif compare_versions(db_version, v := "3.1.0") < 0:
+        db = update_wrapper(db, update_3_1, db_version, v)  # 3.0.x to 3.1.0
+    elif compare_versions(db_version, v := "3.2.0") < 0:
+        db = update_wrapper(db, update_3_2, db_version, v)  # 3.1.x to 3.2.0
+    elif compare_versions(db_version, v := "3.3.0") < 0:
+        db = update_wrapper(db, update_3_3, db_version, v)  # 3.2.x to 3.3.0
+    elif compare_versions(db_version, v := "3.5.0") < 0:
+        db = update_wrapper(db, update_3_5, db_version, v)  # 3.3.0-3.4.x to 3.5.0
+    elif compare_versions(db_version, v := "4.0.0") < 0:
+        db = update_wrapper(db, update_4_0, db_version, v)  # 3.6.0-3.8.x to 4.0.0
+    elif compare_versions(db_version, v := "4.3.0") < 0:
+        db = update_wrapper(db, update_4_3, db_version, v)  # 4.0.0-4.2.x to 4.3.0
+    elif compare_versions(db_version, v := "4.4.0") < 0:
+        db = update_wrapper(db, update_4_4, db_version, v)  # 4.3.x to 4.4.0
+    elif compare_versions(db_version, v := "4.5.0") < 0:
+        db = update_wrapper(db, update_4_5, db_version, v)  # 4.4.x to 4.5.0
+    elif compare_versions(db_version, v := "4.6.0") < 0:
+        db = update_wrapper(db, update_4_6, db_version, v)  # 4.5.x to 4.6.0
+    elif compare_versions(db_version, v := "4.7.0") < 0:
+        db = update_wrapper(db, update_4_7, db_version, v)  # 4.6.x to 4.7.0
+    elif compare_versions(db_version, v := "4.8.0") < 0:
+        db = update_wrapper(db, update_4_8, db_version, v)  # 4.7.x to 4.8.0
+    elif compare_versions(db_version, v := "4.9.0") < 0:
+        db = update_wrapper(db, update_4_9, db_version, v)  # 4.8.x to 4.9.0
+    elif compare_versions(db_version, v := "4.11.0") < 0:
+        db = update_wrapper(db, update_4_11, db_version, v)  # 4.9.0-4.10.x to 4.11.0
+    elif compare_versions(db_version, v := "4.18.0") < 0:
+        db = update_wrapper(db, update_4_18, db_version, v)  # 4.11.0-4.17.x to 4.18.0
     elif compare_versions(db_version, version) < 0:
         return update_version(db, db_version, version)  # Update to latest patch
 
